@@ -130,10 +130,17 @@ class SlimServer:
             player_id = client.player_id
 
             if event_type == EventType.PLAYER_DISCONNECTED:
-                self._players.pop(player_id, None)
+                prev = self._players.pop(player_id, None)
+                if prev is None:
+                    # already cleaned up ?
+                    return
 
             if event_type == EventType.PLAYER_CONNECTED:
-                assert player_id not in self._players
+                prev = self._players.pop(player_id, None)
+                if prev is not None:
+                    # player reconnected while we did not yet cleanup the old socket
+                    prev.disconnect()
+
                 self._players[player_id] = client
 
             # forward all other events as-is
